--- a/cwvreg.py Mon Aug 03 14:14:07 2009 +0200
+++ b/cwvreg.py Mon Aug 03 15:16:47 2009 +0200
@@ -34,7 +34,7 @@
if impl:
return sorted(impl.expected_ifaces)
except AttributeError:
pass # old-style vobject classes with no accepts_interfaces
except:
print 'bad selector %s on %s' % (obj.__select__, obj)
raise
@@ -308,7 +308,7 @@
# we may want to keep interface dependent objects (e.g.for i18n
# catalog generation)
if self.config.cleanup_interface_sobjects:
- # remove vobjects that don't support any available interface
+ # remove appobjects that don't support any available interface
implemented_interfaces = set()
if 'Any' in self.get('etypes', ()):
for etype in self.schema.entities():
@@ -323,7 +323,7 @@
or iface
for iface in ifaces)
if not ('Any' in ifaces or ifaces & implemented_interfaces):
- self.debug('kicking vobject %s (no implemented '
+ self.debug('kicking appobject %s (no implemented '
'interface among %s)', obj, ifaces)
self.unregister(obj)
# clear needs_iface so we don't try to remove some not-anymore-in
@@ -34,7 +34,7 @@
return sorted(impl.expected_ifaces)
except AttributeError:
- pass # old-style vobject classes with no accepts_interfaces
+ pass # old-style appobject classes with no accepts_interfaces
except:
print 'bad selector %s on %s' % (obj.__select__, obj)